models/auth/mfa_challenge_model library

Classes

MfaChallenge
A login that stopped halfway because the account has MFA enabled.

Enums

MfaMethod
Second factors the backend accepts to finish a login.