mfaEnabled property
Whether the account requires a second factor to log in. Only present if
the backend exposes mfaEnabled through its user attribute whitelist.
Implementation
bool? mfaEnabled;
Whether the account requires a second factor to log in. Only present if
the backend exposes mfaEnabled through its user attribute whitelist.
bool? mfaEnabled;